@@ -52,9 +52,9 @@ static const gchar *gda_mdb_provider_get_database (GdaServerProvider *provider,
 static gboolean gda_mdb_provider_change_database (GdaServerProvider *provider,
 						  GdaConnection *cnc,
 						  const gchar *name);
-static gboolean gda_mdb_provider_create_database_cnc (GdaServerProvider *provider,
-						      GdaConnection *cnc,
-						      const gchar *name);
+static gboolean gda_mdb_provider_create_database (GdaServerProvider *provider,
+						  GdaConnection *cnc,
+						  const gchar *name);
 static gboolean gda_mdb_provider_drop_database (GdaServerProvider *provider,
 						GdaConnection *cnc,
 						const gchar *name);
@@ -107,7 +107,7 @@ gda_mdb_provider_class_init (GdaMdbProviderClass *klass)
 	provider_class->get_server_version = gda_mdb_provider_get_server_version;
 	provider_class->get_database = gda_mdb_provider_get_database;
 	provider_class->change_database = gda_mdb_provider_change_database;
-	provider_class->create_database_cnc = gda_mdb_provider_create_database_cnc;
+	provider_class->create_database = gda_mdb_provider_create_database;
 	provider_class->drop_database = gda_mdb_provider_drop_database;
 	provider_class->execute_command = gda_mdb_provider_execute_command;
 	provider_class->begin_transaction = gda_mdb_provider_begin_transaction;
@@ -179,7 +179,7 @@ gda_mdb_provider_new (void)
 static const gchar *
 gda_mdb_provider_get_version (GdaServerProvider *provider)
 {
-	return PACKAGE_VERSION;
+	return VERSION;
 }
 
 /* open_connection handler for the GdaMdbProvider class */
@@ -209,7 +209,7 @@ gda_mdb_provider_open_connection (GdaServerProvider *provider,
 	mdb_cnc = g_new0 (GdaMdbConnection, 1);
 	mdb_cnc->cnc = cnc;
 	mdb_cnc->server_version = NULL;
-	mdb_cnc->mdb = mdb_open (filename, MDB_WRITABLE);
+	mdb_cnc->mdb = mdb_open (filename);
 	if (!mdb_cnc->mdb) {
 		gda_connection_add_error_string (cnc, _("Could not open file %s"), filename);
 		g_free (mdb_cnc);
@@ -303,11 +303,11 @@ gda_mdb_provider_change_database (GdaServerProvider *provider,
 	return FALSE;
 }
 
-/* create_database_cnc handler for the GdaMdbProvider class */
+/* create_database handler for the GdaMdbProvider class */
 static gboolean
-gda_mdb_provider_create_database_cnc (GdaServerProvider *provider,
-				      GdaConnection *cnc,
-				      const gchar *name)
+gda_mdb_provider_create_database (GdaServerProvider *provider,
+				  GdaConnection *cnc,
+				  const gchar *name)
 {
 	return FALSE;
 }
@@ -389,7 +389,7 @@ gda_mdb_provider_execute_command (GdaServerProvider *provider,
 			g_strfreev (arr);
 		}
 		break;
-	default : ;
+	default :
 	}
 
 	return reclist;
@@ -438,7 +438,7 @@ gda_mdb_provider_supports (GdaServerProvider *provider,
 	case GDA_CONNECTION_FEATURE_PROCEDURES :
 	case GDA_CONNECTION_FEATURE_SQL :
 		return TRUE;
-	default : ;
+	default :
 	}
 
 	return FALSE;
@@ -458,7 +458,7 @@ get_mdb_databases (GdaMdbConnection *mdb_cnc)
 
 	l.prev = l.next = NULL;
 	l.data = gda_value_new_string (mdb_cnc->mdb->f->filename);
-	gda_data_model_append_values (model, &l);
+	gda_data_model_append_row (model, &l);
 
 	gda_value_free (l.data);
 
@@ -522,7 +522,7 @@ get_mdb_fields (GdaMdbConnection *mdb_cnc, GdaParameterList *params)
 				value_list = g_list_append (value_list, gda_value_new_string (NULL));
 				value_list = g_list_append (value_list, gda_value_new_string (NULL));
 
-				gda_data_model_append_values (model, value_list);
+				gda_data_model_append_row (model, value_list);
 
 				g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 				g_list_free (value_list);
@@ -571,7 +571,7 @@ get_mdb_procedures (GdaMdbConnection *mdb_cnc)
 			value_list = g_list_append (value_list, gda_value_new_string (NULL));
 			value_list = g_list_append (value_list, gda_value_new_string (NULL));
 
-			gda_data_model_append_values (GDA_DATA_MODEL (model), value_list);
+			gda_data_model_append_row (GDA_DATA_MODEL (model), value_list);
 
 			g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 			g_list_free (value_list);
@@ -614,7 +614,7 @@ get_mdb_tables (GdaMdbConnection *mdb_cnc)
 				value_list = g_list_append (value_list, gda_value_new_string (""));
 				value_list = g_list_append (value_list, gda_value_new_string (""));
 
-				gda_data_model_append_values (model, value_list);
+				gda_data_model_append_row (model, value_list);
 
 				g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 				g_list_free (value_list);
@@ -636,7 +636,7 @@ add_type (GdaDataModel *model, const gchar *typname, const gchar *owner,
 	value_list = g_list_append (value_list, gda_value_new_string (comments));
 	value_list = g_list_append (value_list, gda_value_new_type (type));
 
-	gda_data_model_append_values (model, value_list);
+	gda_data_model_append_row (model, value_list);
 
 	g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 	g_list_free (value_list);
@@ -750,7 +750,7 @@ gda_mdb_provider_execute_sql (GdaMdbProvider *mdbprv, GdaConnection *cnc, const
 	/* allocate bound data */
 	for (c = 0; c < mdb_SQL->num_columns; c++) {
 		MdbSQLColumn *sqlcol;
-		GdaColumn *fa;
+		GdaFieldAttributes *fa;
 
 		bound_data[c] = (gchar *) malloc (MDB_BIND_SIZE);
 		bound_data[c][0] = '\0';
@@ -758,14 +758,14 @@ gda_mdb_provider_execute_sql (GdaMdbProvider *mdbprv, GdaConnection *cnc, const
 
 		/* set description for the field */
 		sqlcol = g_ptr_array_index (mdb_SQL->columns, c);
-		fa = gda_column_new ();
-		gda_column_set_name (fa, sqlcol->name);
-		gda_column_set_defined_size (fa, sqlcol->disp_size);
-		gda_column_set_gdatype (fa, gda_mdb_type_to_gda (sqlcol->bind_type));
+		fa = gda_field_attributes_new ();
+		gda_field_attributes_set_name (fa, sqlcol->name);
+		gda_field_attributes_set_defined_size (fa, sqlcol->disp_size);
+		gda_field_attributes_set_gdatype (fa, gda_mdb_type_to_gda (sqlcol->bind_type));
 
 		/* and add it to the table */
-		gda_table_add_field (model, (const GdaColumn *) fa);
-		gda_column_free (fa);
+		gda_table_add_field (model, (const GdaFieldAttributes *) fa);
+		gda_field_attributes_free (fa);
 	}
 
 	/* read data */
@@ -777,7 +777,7 @@ gda_mdb_provider_execute_sql (GdaMdbProvider *mdbprv, GdaConnection *cnc, const
 		for (c = 0; c < mdb_SQL->num_columns; c++)
 			value_list = g_list_append (value_list, gda_value_new_string (bound_data[c]));
 
-		gda_data_model_append_values (GDA_DATA_MODEL (model), value_list);
+		gda_data_model_append_row (GDA_DATA_MODEL (model), value_list);
 
 		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 		g_list_free (value_list);
